@@ -79,7 +79,7 @@ func commentBitbucketCmd(ctx *config.RunContext) *cobra.Command {
 
 			paths, _ := cmd.Flags().GetStringArray("path")
 
-			body, err := buildCommentBody(cmd, ctx, paths, output.MarkdownOptions{
+			body, hasDiff, err := buildCommentBody(cmd, ctx, paths, output.MarkdownOptions{
 				WillUpdate:          prNumber != 0 && behavior == "update",
 				WillReplace:         prNumber != 0 && behavior == "delete-and-new",
 				IncludeFeedbackLink: true,
@@ -100,7 +100,9 @@ func commentBitbucketCmd(ctx *config.RunContext) *cobra.Command {
 
 			dryRun, _ := cmd.Flags().GetBool("dry-run")
 			if !dryRun {
-				err = commentHandler.CommentWithBehavior(ctx.Context(), behavior, string(body))
+				skipNoDiff, _ := cmd.Flags().GetBool("skip-no-diff")
+
+				posted, err := commentHandler.CommentWithBehavior(ctx.Context(), !hasDiff && skipNoDiff, behavior, string(body))
 				if err != nil {
 					return err
 				}
@@ -111,7 +113,11 @@ func commentBitbucketCmd(ctx *config.RunContext) *cobra.Command {
 					logging.Logger.WithError(err).Error("could not report infracost-comment event")
 				}
 
-				cmd.Println("Comment posted to Bitbucket")
+				if posted {
+					cmd.Println("Comment posted to Bitbucket")
+				} else {
+					cmd.Println("Comment not posted to Bitbucket (skipped)")
+				}
 			} else {
 				cmd.Println(string(body))
 				cmd.Println("Comment not posted to Bitbucket (--dry-run was specified)")
