@@ -6,7 +6,6 @@ import (
 	"fmt"
 	"io"
 	"os"
-	"runtime"
 	"runtime/debug"
 	"sort"
 	"strings"
@@ -147,7 +146,7 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 	r.Currency = runCtx.Config.Currency
 	r.Metadata = output.NewMetadata(runCtx)
 
-	if runCtx.IsCloudEnabled() {
+	if runCtx.IsCloudUploadEnabled() {
 		dashboardClient := apiclient.NewDashboardAPIClient(runCtx)
 		result, err := dashboardClient.AddRun(runCtx, r)
 		if err != nil {
@@ -156,7 +155,7 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 
 		r.RunID, r.ShareURL = result.RunID, result.ShareURL
 	} else {
-		log.Debug("Skipping sending project results since Infracost Cloud is not enabled.")
+		log.Debug("Skipping sending project results since Infracost Cloud upload is not enabled.")
 	}
 
 	format := strings.ToLower(runCtx.Config.Format)
@@ -259,7 +258,7 @@ func newParallelRunner(cmd *cobra.Command, runCtx *config.RunContext) (*parallel
 		prior = &snapshot
 	}
 
-	parallelism, err := getParallelism(cmd, runCtx)
+	parallelism, err := runCtx.GetParallelism()
 	if err != nil {
 		return nil, err
 	}
@@ -794,33 +793,6 @@ func (r *parallelRunner) generateUsageFile(ctx *config.ProjectContext, provider
 	return nil
 }
 
-func getParallelism(cmd *cobra.Command, runCtx *config.RunContext) (int, error) {
-	var parallelism int
-
-	if runCtx.Config.Parallelism == nil {
-		parallelism = 4
-		numCPU := runtime.NumCPU()
-		if numCPU*4 > parallelism {
-			parallelism = numCPU * 4
-		}
-		if parallelism > 16 {
-			parallelism = 16
-		}
-	} else {
-		parallelism = *runCtx.Config.Parallelism
-
-		if parallelism < 0 {
-			return parallelism, fmt.Errorf("parallelism must be a positive number")
-		}
-
-		if parallelism > 16 {
-			return parallelism, fmt.Errorf("parallelism must be less than 16")
-		}
-	}
-
-	return parallelism, nil
-}
-
 func loadRunFlags(cfg *config.Config, cmd *cobra.Command) error {
 	hasPathFlag := cmd.Flags().Changed("path")
 	hasConfigFile := cmd.Flags().Changed("config-file")
