@@ -13,7 +13,6 @@ import (
 	"github.com/hashicorp/hcl/v2"
 	"github.com/hashicorp/hcl/v2/ext/tryfunc"
 	"github.com/hashicorp/hcl/v2/ext/typeexpr"
-	"github.com/hashicorp/hcl/v2/hclsyntax"
 	"github.com/sirupsen/logrus"
 	yaml "github.com/zclconf/go-cty-yaml"
 	"github.com/zclconf/go-cty/cty"
@@ -514,81 +513,52 @@ func (e *Evaluator) getSourceValue(from *Block) cty.Value {
 
 func (e *Evaluator) evaluateVariable(b *Block) (cty.Value, error) {
 	if b.Label() == "" {
-		return cty.NilVal, fmt.Errorf("empty label - cannot resolve")
+		return cty.DynamicVal, fmt.Errorf("empty label - cannot resolve")
 	}
 
 	attributes := b.AttributesAsMap()
 	if attributes == nil {
-		return cty.NilVal, fmt.Errorf("cannot resolve variable with no attributes")
+		return cty.DynamicVal, fmt.Errorf("cannot resolve variable with no attributes")
 	}
 
 	attrType := attributes["type"]
 	if override, exists := e.inputVars[b.Label()]; exists {
-		return convertType(override, attrType), nil
+		return e.convertType(b, override, attrType)
 	}
 
 	if def, exists := attributes["default"]; exists {
-		if attrType == nil {
-			return def.Value(), nil
-		}
-
-		ty, diag := typeexpr.TypeConstraint(attrType.HCLAttr.Expr)
-		if diag.HasErrors() {
-			e.logger.WithError(diag).Debugf("error trying to convert variable %s to type %s", b.Label(), attrType.AsString())
-			return def.Value(), nil
-		}
-		return convert.Convert(def.Value(), ty)
+		return e.convertType(b, def.Value(), attrType)
 	}
 
-	return convertType(cty.NilVal, attrType), errorNoVarValue
-}
-
-func convertType(val cty.Value, attribute *Attribute) cty.Value {
-	if attribute == nil {
-		return val
-	}
-
-	var t string
-	switch v := attribute.HCLAttr.Expr.(type) {
-	case *hclsyntax.ScopeTraversalExpr:
-		t = v.Traversal.RootName()
-	case *hclsyntax.LiteralValueExpr:
-		t = attribute.AsString()
-	}
-
-	switch t {
-	case "string":
-		return valueToType(val, cty.String)
-	case "number":
-		return valueToType(val, cty.Number)
-	case "bool":
-		return valueToType(val, cty.Bool)
-	}
-
-	return val
-}
-
-func valueToType(val cty.Value, want cty.Type) cty.Value {
-	if val == cty.NilVal {
-		return val
-	}
-
-	newVal, err := convert.Convert(val, want)
+	c, err := e.convertType(b, cty.DynamicVal, attrType)
 	if err != nil {
-		return val
+		return c, err
 	}
 
-	return newVal
+	return c, errorNoVarValue
+}
+
+func (e *Evaluator) convertType(b *Block, val cty.Value, attrType *Attribute) (cty.Value, error) {
+	if attrType == nil || val.IsNull() || !val.IsKnown() {
+		return val, nil
+	}
+
+	ty, diag := typeexpr.TypeConstraint(attrType.HCLAttr.Expr)
+	if diag.HasErrors() {
+		e.logger.WithError(diag).Debugf("error trying to convert variable %s to type %s", b.Label(), attrType.AsString())
+		return val, nil
+	}
+	return convert.Convert(val, ty)
 }
 
 func (e *Evaluator) evaluateOutput(b *Block) (cty.Value, error) {
 	if b.Label() == "" {
-		return cty.NilVal, fmt.Errorf("empty label - cannot resolve")
+		return cty.DynamicVal, fmt.Errorf("empty label - cannot resolve")
 	}
 
 	attribute := b.GetAttribute("value")
 	if attribute == nil {
-		return cty.NilVal, fmt.Errorf("cannot resolve variable with no attributes")
+		return cty.DynamicVal, fmt.Errorf("cannot resolve variable with no attributes")
 	}
 	return attribute.Value(), nil
 }
@@ -677,7 +647,7 @@ func (e *Evaluator) evaluateResource(b *Block, values map[string]cty.Value) cty.
 func expandCountBlockToValue(b *Block, existingValues map[string]cty.Value) cty.Value {
 	k := b.Index()
 	if k == nil {
-		return cty.NilVal
+		return cty.DynamicVal
 	}
 
 	vals := existingValues[stripCount(b.Labels()[1])]
@@ -700,14 +670,14 @@ func expandCountBlockToValue(b *Block, existingValues map[string]cty.Value) cty.
 func (e *Evaluator) expandedEachBlockToValue(b *Block, existingValues map[string]cty.Value) cty.Value {
 	k := b.Key()
 	if k == nil {
-		return cty.NilVal
+		return cty.DynamicVal
 	}
 
 	ob := make(map[string]cty.Value)
 
 	name := b.Labels()[1]
 	eachMap := existingValues[stripCount(name)]
-	if eachMap != cty.NilVal {
+	if !eachMap.IsNull() && eachMap.IsKnown() {
 		if !eachMap.Type().IsObjectType() && !eachMap.Type().IsMapType() {
 			e.logger.WithFields(logrus.Fields{
 				"block": b.Label(),
@@ -756,13 +726,7 @@ func (e *Evaluator) loadModule(b *Block) (*ModuleCall, error) {
 		key = nestedModReplace.ReplaceAllString(key, ".")
 		key = modArrayPartReplace.ReplaceAllString(key, "")
 
-		for _, module := range e.moduleMetadata.Modules {
-			if module.Key == key {
-				modulePath = filepath.Clean(filepath.Join(e.module.RootPath, module.Dir))
-				break
-			}
-		}
-
+		modulePath = e.moduleMetadata.FindModulePath(key)
 		e.logger.Debugf("using path '%s' for module '%s' based on key '%s'", modulePath, b.FullName(), key)
 	}
 
