@@ -121,7 +121,7 @@ func (p *PlanProvider) generatePlanJSON() ([]byte, error) {
 	spinner := ui.NewSpinner("Running terraform show", p.spinnerOpts)
 	defer spinner.Fail()
 
-	j, err := p.runShow(opts, spinner, planPath)
+	j, err := p.runShow(opts, spinner, planPath, false)
 	if err == nil {
 		p.cachedPlanJSON = j
 	}
