@@ -18,6 +18,7 @@ import (
 	tgconfig "github.com/gruntwork-io/terragrunt/config"
 	tgconfigstack "github.com/gruntwork-io/terragrunt/configstack"
 	tgerrors "github.com/gruntwork-io/terragrunt/errors"
+	"github.com/gruntwork-io/terragrunt/options"
 	tgoptions "github.com/gruntwork-io/terragrunt/options"
 	"github.com/gruntwork-io/terragrunt/util"
 	"github.com/hashicorp/go-getter"
@@ -170,6 +171,26 @@ func (p *TerragruntHCLProvider) LoadResources(usage map[string]*schema.UsageData
 	return allProjects, nil
 }
 
+func (p *TerragruntHCLProvider) initTerraformVarFiles(tfVarFiles []string, extraArgs []tgconfig.TerraformExtraArguments, basePath string) []string {
+	v := tfVarFiles
+
+	for _, extraArg := range extraArgs {
+		varFiles := extraArg.GetVarFiles(p.logger)
+		for _, f := range varFiles {
+			absBasePath, _ := filepath.Abs(basePath)
+			relPath, err := filepath.Rel(absBasePath, f)
+			if err != nil {
+				p.logger.Debugf("Error processing var-file, could not get relative path for %s from %s", f, basePath)
+				continue
+			}
+
+			v = append(v, relPath)
+		}
+	}
+
+	return v
+}
+
 func (p *TerragruntHCLProvider) initTerraformVars(tfVars map[string]string, inputs map[string]interface{}) map[string]string {
 	m := make(map[string]string, len(tfVars)+len(inputs))
 	for k, v := range tfVars {
@@ -225,7 +246,15 @@ func (p *TerragruntHCLProvider) prepWorkingDirs() ([]*terragruntWorkingDirInfo,
 		Parallelism: 1,
 	}
 
-	s, err := tgconfigstack.FindStackInSubfolders(terragruntOptions)
+	terragruntConfigFiles, err := tgconfig.FindConfigFilesInPath(terragruntOptions.WorkingDir, terragruntOptions)
+	if err != nil {
+		return nil, err
+	}
+	// Filter these config files against the exclude paths so Terragrunt doesn't even try to evaluate them
+	terragruntConfigFiles = p.filterExcludedPaths(terragruntConfigFiles)
+
+	howThesePathsWereFound := fmt.Sprintf("Terragrunt config file found in a subdirectory of %s", terragruntOptions.WorkingDir)
+	s, err := createStackForTerragruntConfigPaths(terragruntOptions.WorkingDir, terragruntConfigFiles, terragruntOptions, howThesePathsWereFound)
 	if err != nil {
 		return nil, err
 	}
@@ -252,6 +281,22 @@ func (p *TerragruntHCLProvider) prepWorkingDirs() ([]*terragruntWorkingDirInfo,
 	return workingDirsToEstimate, nil
 }
 
+func (p *TerragruntHCLProvider) filterExcludedPaths(paths []string) []string {
+	isSkipped := buildExcludedPathsMatcher(p.Path, p.excludedPaths)
+
+	var filteredPaths []string
+
+	for _, path := range paths {
+		if !isSkipped(path) {
+			filteredPaths = append(filteredPaths, path)
+		} else {
+			p.logger.Debugf("skipping path %s as it is marked as excluded by --exclude-path", path)
+		}
+	}
+
+	return filteredPaths
+}
+
 // runTerragrunt evaluates a Terragrunt directory with the given opts. This method is called from the
 // Terragrunt internal libs as part of the Terraform project evaluation. runTerragrunt is called with for all of the folders
 // in a Terragrunt project. Folders that have outputs that are used by other folders are evaluated first.
@@ -329,11 +374,20 @@ func (p *TerragruntHCLProvider) runTerragrunt(opts *tgoptions.TerragruntOptions)
 
 	pconfig := *p.ctx.ProjectConfig // clone the projectConfig
 	pconfig.Path = info.workingDir
+
+	if terragruntConfig.Terraform != nil {
+		pconfig.TerraformVarFiles = p.initTerraformVarFiles(pconfig.TerraformVarFiles, terragruntConfig.Terraform.ExtraArgs, pconfig.Path)
+	}
 	pconfig.TerraformVars = p.initTerraformVars(pconfig.TerraformVars, terragruntConfig.Inputs)
 
+	ops := []hcl.Option{
+		hcl.OptionWithSpinner(p.ctx.RunContext.NewSpinner),
+	}
 	inputs, err := convertToCtyWithJson(terragruntConfig.Inputs)
 	if err != nil {
 		p.logger.Debugf("Failed to build Terragrunt inputs for: %s err: %s", info.workingDir, err)
+	} else {
+		ops = append(ops, hcl.OptionWithRawCtyInput(inputs))
 	}
 
 	fields := p.logger.Data
@@ -342,8 +396,7 @@ func (p *TerragruntHCLProvider) runTerragrunt(opts *tgoptions.TerragruntOptions)
 	h, err := NewHCLProvider(
 		config.NewProjectContext(p.ctx.RunContext, &pconfig, fields),
 		&HCLProviderConfig{CacheParsingModules: true},
-		hcl.OptionWithSpinner(p.ctx.RunContext.NewSpinner),
-		hcl.OptionWithRawCtyInput(inputs),
+		ops...,
 	)
 	if err != nil {
 		return nil, fmt.Errorf("could not create provider for Terragrunt generated dir %w", err)
@@ -362,22 +415,55 @@ func (p *TerragruntHCLProvider) runTerragrunt(opts *tgoptions.TerragruntOptions)
 	return info, nil
 }
 
+func buildExcludedPathsMatcher(fullPath string, excludedDirs []string) func(string) bool {
+	var excludedMatches []string
+
+	for _, dir := range excludedDirs {
+		var absoluteDir string
+
+		if filepath.IsAbs(dir) {
+			absoluteDir = dir
+		} else {
+			absoluteDir, _ = filepath.Abs(filepath.Join(fullPath, dir))
+		}
+
+		globs, err := filepath.Glob(absoluteDir)
+		if err == nil {
+			for _, m := range globs {
+				excludedMatches = append(excludedMatches, m)
+			}
+		}
+	}
+
+	return func(dir string) bool {
+		absoluteDir, _ := filepath.Abs(dir)
+
+		for _, match := range excludedMatches {
+			if strings.HasPrefix(absoluteDir, match) {
+				return true
+			}
+		}
+
+		return false
+	}
+}
+
 func convertToCtyWithJson(val interface{}) (cty.Value, error) {
 	jsonBytes, err := json.Marshal(val)
 	if err != nil {
-		return cty.NilVal, fmt.Errorf("could not marshal terragrunt inputs %w", err)
+		return cty.DynamicVal, fmt.Errorf("could not marshal terragrunt inputs %w", err)
 	}
 	var ctyJsonVal ctyJson.SimpleJSONValue
 	if err := ctyJsonVal.UnmarshalJSON(jsonBytes); err != nil {
-		return cty.NilVal, fmt.Errorf("could not unmarshall terragrunt inputs %w", err)
+		return cty.DynamicVal, fmt.Errorf("could not unmarshall terragrunt inputs %w", err)
 	}
 	return ctyJsonVal.Value, nil
 }
 
 var (
-	depRegexp   = regexp.MustCompile(`dependency\.[\w.\[\]"]+`)
+	depRegexp   = regexp.MustCompile(`dependency\.[\w\-.\[\]"]+`)
 	indexRegexp = regexp.MustCompile(`(\w+)\[(\d+)]`)
-	mapRegexp   = regexp.MustCompile(`(\w+)\["([\w\d]+)"]`)
+	mapRegexp   = regexp.MustCompile(`\["([\w\d]+)"]`)
 )
 
 func (p *TerragruntHCLProvider) fetchDependencyOutputs(opts *tgoptions.TerragruntOptions) cty.Value {
@@ -448,10 +534,18 @@ func mergeObjectWithDependencyMap(valueMap map[string]cty.Value, pieces []string
 		return mergeListWithDependencyMap(valueMap, pieces, indexKeys[1], index)
 	}
 
-	mapKeys := mapRegexp.FindStringSubmatch(key)
+	mapKeys := mapRegexp.FindAllStringSubmatch(key, -1)
 	if len(mapKeys) != 0 {
-		key = mapKeys[1]
-		pieces = append([]string{pieces[0], mapKeys[2]}, pieces[1:]...)
+		keys := []string{pieces[0]}
+		for _, match := range mapKeys {
+			keys = append(keys, match[1])
+		}
+
+		split := strings.Split(key, "[")
+		key = split[0]
+		pieces = append(keys, pieces[1:]...)
+	} else {
+		key = strings.TrimSuffix(key, "]")
 	}
 
 	if len(pieces) == 1 {
@@ -465,6 +559,12 @@ func mergeObjectWithDependencyMap(valueMap map[string]cty.Value, pieces []string
 
 	if v, ok := valueMap[key]; ok {
 		if v.CanIterateElements() {
+			if isList(v) {
+				index, _ := strconv.Atoi(pieces[1])
+
+				return mergeListWithDependencyMap(valueMap, pieces[1:], key, index)
+			}
+
 			valueMap[key] = cty.ObjectVal(mergeObjectWithDependencyMap(v.AsValueMap(), pieces[1:]))
 			return valueMap
 		}
@@ -477,11 +577,15 @@ func mergeObjectWithDependencyMap(valueMap map[string]cty.Value, pieces []string
 	return valueMap
 }
 
+func isList(v cty.Value) bool {
+	return v.Type().IsTupleType() || v.Type().IsListType()
+}
+
 func mergeListWithDependencyMap(valueMap map[string]cty.Value, pieces []string, key string, index int) map[string]cty.Value {
 	indexVal := cty.NumberIntVal(int64(index))
 
 	if len(pieces) == 1 {
-		if v, ok := valueMap[key]; ok && (v.Type().IsListType() || v.Type().IsTupleType()) {
+		if v, ok := valueMap[key]; ok && isList(v) {
 			// if we have the index already in the dependency output, and it is known use the existing value.
 			// If the value is unknown we need to override it wil a mock as Terragrunt will explode when they
 			// try and marshal the cty values to JSON.
@@ -519,7 +623,7 @@ func mergeListWithDependencyMap(valueMap map[string]cty.Value, pieces []string,
 
 	mockValue := cty.ObjectVal(mergeObjectWithDependencyMap(map[string]cty.Value{}, pieces[1:]))
 
-	if v, ok := valueMap[key]; ok && (v.Type().IsListType() || v.Type().IsTupleType()) {
+	if v, ok := valueMap[key]; ok && isList(v) {
 		// if we have the index already in the dependency output, and it is known use the existing value.
 		// If the value is unknown we need to override it wil a mock as Terragrunt will explode when they
 		// try and marshal the cty values to JSON.
@@ -595,7 +699,7 @@ func (p *TerragruntHCLProvider) fetchModuleOutputs(opts *tgoptions.TerragruntOpt
 			}
 
 			if len(out) > 0 {
-				encoded, err := gocty.ToCtyValue(out, generateTypeFromValuesMap(out))
+				encoded, err := toCtyValue(out, generateTypeFromValuesMap(out))
 				if err == nil {
 					return encoded, nil
 				}
@@ -608,6 +712,18 @@ func (p *TerragruntHCLProvider) fetchModuleOutputs(opts *tgoptions.TerragruntOpt
 	return outputs, nil
 }
 
+func toCtyValue(val map[string]cty.Value, ty cty.Type) (v cty.Value, err error) {
+	defer func() {
+		if e := recover(); e != nil {
+			trace := debug.Stack()
+			v = cty.DynamicVal
+			err = fmt.Errorf("recovered from cty panic converting value (%+v) to type (%s) err: %s trace: %s", val, ty.GoString(), e, trace)
+		}
+	}()
+
+	return gocty.ToCtyValue(val, ty)
+}
+
 // generateTypeFromValuesMap takes a values map and returns an object type that has the same number of fields, but
 // bound to each type of the underlying evaluated expression. This is the only way the HCL decoder will be happy, as
 // object type is the only map type that allows different types for each attribute (cty.Map requires all attributes to
@@ -876,6 +992,26 @@ type terragruntDependency struct {
 	Remain       hcl2.Body             `hcl:",remain"`
 }
 
+// Find all the Terraform modules in the folders that contain the given Terragrunt config files and assemble those
+// modules into a Stack object
+func createStackForTerragruntConfigPaths(path string, terragruntConfigPaths []string, terragruntOptions *options.TerragruntOptions, howThesePathsWereFound string) (*tgconfigstack.Stack, error) {
+	if len(terragruntConfigPaths) == 0 {
+		return nil, tgerrors.WithStackTrace(tgconfigstack.NoTerraformModulesFound)
+	}
+
+	modules, err := tgconfigstack.ResolveTerraformModules(terragruntConfigPaths, terragruntOptions, howThesePathsWereFound)
+	if err != nil {
+		return nil, err
+	}
+
+	stack := &tgconfigstack.Stack{Path: path, Modules: modules}
+	if err := stack.CheckForCycles(); err != nil {
+		return nil, err
+	}
+
+	return stack, nil
+}
+
 // decodeDependencyBlocks parses the file at filename and returns a map containing all the hcl blocks with the "dependency" label.
 // The map is keyed by the full path of the config_path attribute specified in the dependency block.
 func decodeDependencyBlocks(filename string, terragruntOptions *tgoptions.TerragruntOptions, dependencyOutputs *cty.Value, include *tgconfig.IncludeConfig) (map[string]tgconfig.Dependency, error) {
