@@ -2,10 +2,12 @@ package aws
 
 import (
 	"context"
+	"math"
+
 	"github.com/infracost/infracost/internal/resources"
 	"github.com/infracost/infracost/internal/schema"
+	"github.com/infracost/infracost/internal/usage"
 	"github.com/infracost/infracost/internal/usage/aws"
-	"math"
 
 	"github.com/shopspring/decimal"
 )
@@ -51,10 +53,45 @@ func (a *LambdaFunction) BuildResource() *schema.Resource {
 
 	var monthlyRequests *decimal.Decimal
 	var gbSeconds *decimal.Decimal
+	var costComponents []*schema.CostComponent
+
+	costComponents = append(costComponents, &schema.CostComponent{
+		Name:            "Requests",
+		Unit:            "1M requests",
+		UnitMultiplier:  decimal.NewFromInt(1000000),
+		MonthlyQuantity: monthlyRequests,
+		ProductFilter: &schema.ProductFilter{
+			VendorName:    strPtr("aws"),
+			Region:        strPtr(a.Region),
+			Service:       strPtr("AWSLambda"),
+			ProductFamily: strPtr("Serverless"),
+			AttributeFilters: []*schema.AttributeFilter{
+				{Key: "group", Value: strPtr("AWS-Lambda-Requests")},
+				{Key: "usagetype", ValueRegex: strPtr("/Request/")},
+			},
+		},
+	},
+	)
 
 	if a.MonthlyRequests != nil {
 		monthlyRequests = decimalPtr(decimal.NewFromInt(*a.MonthlyRequests))
 		gbSeconds = decimalPtr(calculateGBSeconds(memorySize, averageRequestDuration, *monthlyRequests))
+
+		gbRequestTiers := []int{6000000000, 9000000000, 15000000000}
+		gbSecondQuantities := usage.CalculateTierBuckets(*gbSeconds, gbRequestTiers)
+
+		costComponents = append(costComponents, a.durationCostComponent("Duration (first 6B)", "0", &gbSecondQuantities[0]))
+
+		if gbSecondQuantities[1].GreaterThan(decimal.NewFromInt(0)) {
+			costComponents = append(costComponents, a.durationCostComponent("Duration (next 9B)", "6000000000", &gbSecondQuantities[1]))
+		}
+
+		if gbSecondQuantities[2].GreaterThanOrEqual(decimal.NewFromInt(0)) {
+			costComponents = append(costComponents, a.durationCostComponent("Duration (over 15B)", "15000000000", &gbSecondQuantities[2]))
+		}
+
+	} else {
+		costComponents = append(costComponents, a.durationCostComponent("Duration (first 6B)", "0", gbSeconds))
 	}
 
 	estimate := func(ctx context.Context, values map[string]interface{}) error {
@@ -72,46 +109,10 @@ func (a *LambdaFunction) BuildResource() *schema.Resource {
 	}
 
 	return &schema.Resource{
-		Name:        a.Address,
-		UsageSchema: a.UsageSchema(),
-		CostComponents: []*schema.CostComponent{
-			{
-				Name:            "Requests",
-				Unit:            "1M requests",
-				UnitMultiplier:  decimal.NewFromInt(1000000),
-				MonthlyQuantity: monthlyRequests,
-				ProductFilter: &schema.ProductFilter{
-					VendorName:    strPtr("aws"),
-					Region:        strPtr(a.Region),
-					Service:       strPtr("AWSLambda"),
-					ProductFamily: strPtr("Serverless"),
-					AttributeFilters: []*schema.AttributeFilter{
-						{Key: "group", Value: strPtr("AWS-Lambda-Requests")},
-						{Key: "usagetype", ValueRegex: strPtr("/Request/")},
-					},
-				},
-			},
-			{
-				Name:            "Duration",
-				Unit:            "GB-seconds",
-				UnitMultiplier:  decimal.NewFromInt(1),
-				MonthlyQuantity: gbSeconds,
-				ProductFilter: &schema.ProductFilter{
-					VendorName:    strPtr("aws"),
-					Region:        strPtr(a.Region),
-					Service:       strPtr("AWSLambda"),
-					ProductFamily: strPtr("Serverless"),
-					AttributeFilters: []*schema.AttributeFilter{
-						{Key: "group", Value: strPtr("AWS-Lambda-Duration")},
-						{Key: "usagetype", ValueRegex: strPtr("/GB-Second/")},
-					},
-				},
-				PriceFilter: &schema.PriceFilter{
-					StartUsageAmount: strPtr("0"),
-				},
-			},
-		},
-		EstimateUsage: estimate,
+		Name:           a.Address,
+		UsageSchema:    a.UsageSchema(),
+		CostComponents: costComponents,
+		EstimateUsage:  estimate,
 	}
 }
 
@@ -120,3 +121,25 @@ func calculateGBSeconds(memorySize decimal.Decimal, averageRequestDuration decim
 	seconds := averageRequestDuration.Ceil().Div(decimal.NewFromInt(1000)) // Round up to closest 1ms and convert to seconds
 	return monthlyRequests.Mul(gb).Mul(seconds)
 }
+
+func (a *LambdaFunction) durationCostComponent(displayName string, usageTier string, quantity *decimal.Decimal) *schema.CostComponent {
+	return &schema.CostComponent{
+		Name:            displayName,
+		Unit:            "GB-seconds",
+		UnitMultiplier:  decimal.NewFromInt(1),
+		MonthlyQuantity: quantity,
+		ProductFilter: &schema.ProductFilter{
+			VendorName:    strPtr("aws"),
+			Region:        strPtr(a.Region),
+			Service:       strPtr("AWSLambda"),
+			ProductFamily: strPtr("Serverless"),
+			AttributeFilters: []*schema.AttributeFilter{
+				{Key: "group", Value: strPtr("AWS-Lambda-Duration")},
+				{Key: "usagetype", ValueRegex: strPtr("/GB-Second/")},
+			},
+		},
+		PriceFilter: &schema.PriceFilter{
+			StartUsageAmount: strPtr(usageTier),
+		},
+	}
+}
